package com.company.tldrawflow.ui.component

import com.vaadin.flow.component.*
import com.vaadin.flow.component.dependency.CssImport
import com.vaadin.flow.component.dependency.JsModule
import com.vaadin.flow.component.dependency.NpmPackage
import com.vaadin.flow.shared.Registration

@Tag("demo-slider")
@NpmPackage(value = "jquery", version = "1.9.1")
@NpmPackage(value = "jquery-ui", version = "1.13.2")
@CssImport("jquery-ui/dist/themes/base/jquery-ui.css")
@JsModule("./component/slider.js")
class Slider : Component(), HasSize {
    var min: Int
        get() = element.getProperty(MIN_PROPERTY, 0)
        set(min) {
            element.setProperty(MIN_PROPERTY, min.toDouble())
        }

    var max: Int
        get() = element.getProperty(MAX_PROPERTY, 100)
        set(max) {
            element.setProperty(MAX_PROPERTY, max.toDouble())
        }

    @get:Synchronize(property = VALUE_PROPERTY, value = [SLIDE_CHANGED_EVENT])
    var value: Int
        get() = element.getProperty(VALUE_PROPERTY, 0)
        set(value) {
            element.setProperty(VALUE_PROPERTY, value.toDouble())
        }

    fun addValueChangeListener(listener: ComponentEventListener<SlideChangedEvent?>?): Registration {
        return addListener(SlideChangedEvent::class.java, listener)
    }

    @DomEvent(SLIDE_CHANGED_EVENT)
    class SlideChangedEvent(
        source: Slider, fromClient: Boolean,
        @param:EventData("event.detail.value") var value: Int
    ) :
        ComponentEvent<Slider?>(source, fromClient)

    companion object {
        const val VALUE_PROPERTY: String = "value"
        const val MIN_PROPERTY: String = "min"
        const val MAX_PROPERTY: String = "max"
        const val SLIDE_CHANGED_EVENT: String = "custom-slide-changed"
    }
}